from os.path import join, dirname


VERSION_FILE = join(dirname(__file__), "VERSION")


def get_version():
    with open(VERSION_FILE, 'r') as ver:
        return ver.readline().strip()


VERSION = get_version()



# Start ignoring PyImportSortBear because of dependency chains!
from coala_utils.string_processing.Match import Match
from coala_utils.string_processing.InBetweenMatch import InBetweenMatch
from coala_utils.string_processing.Core import (
     search_for, unescaped_search_for, split, unescaped_split,
     search_in_between, unescaped_search_in_between, nested_search_in_between,
     escape, convert_to_raw, unescape, unescaped_rstrip, unescaped_strip,
     position_is_escaped)
# Stop ignoring



# -*- coding: utf-8 -*-

import appdirs
import re

# Start ignoring PyImportSortBear, PyLintBear as BUS_NAME is imported as a
# constant from other files.
from coala_utils import VERSION
# Stop ignoring

TRUE_STRINGS = ['1',
                "on",
                'y',
                'yes',
                "yeah",
                "sure",
                'true',
                'definitely',
                'yup',
                'right']

FALSE_STRINGS = ['0',
                 'off',
                 'n',
                 'no',
                 'nope',
                 'nah',
                 'false',
                 'wrong',
                 'none']

URL_REGEX = re.compile(
    r'^(?:(?:http|ftp)[s]?://)?'  # scheme
    r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+'  # domain name
    r'(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|'
    r'localhost|'  # OR localhost
    r'(?:\d{1,3}\.){3}\d{1,3})'  # OR an ip
    r'(?::\d+)?'  # optional port number
    r'(?:/?|[/?]\S+)$',  # path
    re.IGNORECASE)



from coala_utils import VERSION
from coala_utils import get_version
from distutils.core import setup

setup(
  name='coala_utils',
  packages=['coala_utils'],
  version=VERSION,
  description='A collection of coala utilities.',
  author='Adrian Zatreanu',
  author_email='adrianzatreanu1@gmail.com',
  maintainers={'Adrian Zatreanu', 'Alexandros Dimos', 'Lasse Schuirmann'},
  url='https://gitlab.com/coala/coala-utils',
  package_data={'coala_utils': ["VERSION"]},
  keywords=['coala', 'utils', 'bears', 'decorators'],
  classifiers=[
              'Development Status :: 4 - Beta',
              'Environment :: Console',
              'Environment :: MacOS X',
              'Environment :: Win32 (MS Windows)',

              'Intended Audience :: Science/Research',
              'Intended Audience :: Developers',

              'License :: OSI Approved :: MIT License',

              'Operating System :: OS Independent',

              'Programming Language :: Python :: Implementation :: CPython',
              'Programming Language :: Python :: 3.3',
              'Programming Language :: Python :: 3.4',
              'Programming Language :: Python :: 3.5',
              'Programming Language :: Python :: 3 :: Only'],
)
